@@ -1,9 +1,11 @@
 """CLI for the Skyplane object store"""
 import subprocess
+import time
 from functools import partial
 from pathlib import Path
 from shlex import split
 import traceback
+from urllib import request
 import uuid
 import os
 
@@ -14,7 +16,7 @@ import skyplane.cli.usage.definitions
 import skyplane.cli.usage.client
 from skyplane import GB
 from skyplane.cli.usage.client import UsageClient, UsageStatsStatus
-from skyplane.replicate.replicator_client import ReplicatorClient
+from skyplane.replicate.replicator_client import ReplicatorClient, TransferStats
 
 import typer
 from rich.progress import Progress, SpinnerColumn, TextColumn
@@ -23,10 +25,9 @@ import skyplane.cli.cli_aws
 import skyplane.cli.cli_azure
 import skyplane.cli.cli_config
 import skyplane.cli.cli_internal as cli_internal
-import skyplane.cli.cli_solver
 import skyplane.cli.experiments
 from skyplane import cloud_config, config_path, exceptions, skyplane_root
-from skyplane.cli.common import print_header, console
+from skyplane.cli.common import print_header, console, print_stats_completed
 from skyplane.cli.cli_impl.cp_replicate import (
     enrich_dest_objs,
     generate_full_transferobjlist,
@@ -39,6 +40,7 @@ from skyplane.cli.cli_impl.cp_replicate_fallback import (
     replicate_onprem_sync_cmd,
     replicate_small_cp_cmd,
     replicate_small_sync_cmd,
+    get_usage_gbits,
 )
 from skyplane.replicate.replication_plan import ReplicationJob
 from skyplane.cli.cli_impl.init import load_aws_config, load_azure_config, load_gcp_config
@@ -57,7 +59,6 @@ app.add_typer(skyplane.cli.experiments.app, name="experiments")
 app.add_typer(skyplane.cli.cli_aws.app, name="aws")
 app.add_typer(skyplane.cli.cli_azure.app, name="azure")
 app.add_typer(skyplane.cli.cli_config.app, name="config")
-app.add_typer(skyplane.cli.cli_solver.app, name="solver")
 
 
 @app.command()
@@ -73,7 +74,7 @@ def cp(
     max_instances: int = typer.Option(cloud_config.get_flag("max_instances"), "--max-instances", "-n", help="Number of gateways"),
     # solver
     solve: bool = typer.Option(False, help="If true, will use solver to optimize transfer, else direct path is chosen"),
-    solver_required_throughput_gbits: float = typer.Option(4, help="Solver option: Required throughput in Gbps"),
+    solver_target_tput_per_vm_gbits: float = typer.Option(4, help="Solver option: Required throughput in Gbps"),
     solver_throughput_grid: Path = typer.Option(
         skyplane_root / "profiles" / "throughput.csv", "--throughput-grid", help="Throughput grid file"
     ),
@@ -106,8 +107,8 @@ def cp(
     :type max_instances: int
     :param solve: If true, will use solver to optimize transfer, else direct path is chosen
     :type solve: bool
-    :param solver_required_throughput_gbits: The required throughput in Gbps when using the solver (default: 4)
-    :type solver_required_throughput_gbits: float
+    :param throughput_per_instance_gbits: The required throughput in Gbps when using the solver (default: 4)
+    :type throughput_per_instance_gbits: float
     :param solver_throughput_grid: The throughput grid profile to use for the solver, defaults to author-provided profile
     :type solver_throughput_grid: Path
     :param solver_verbose: If true, will print out the solver's output, defaults to False
@@ -144,7 +145,26 @@ def cp(
         cmd = replicate_onprem_cp_cmd(src, dst, recursive)
         if cmd:
             typer.secho(f"Delegating to: {cmd}", fg="yellow")
-            os.system(cmd)
+            start = time.perf_counter()
+            rc = os.system(cmd)
+            request_time = time.perf_counter() - start
+
+            # calculate gbits and throughput
+            if provider_src == "local":
+                client = ObjectStoreInterface.create(dst_region_tag, bucket_dst)
+                dst_region_tag = client.region_tag()
+                size_byte = get_usage_gbits(src)
+            else:
+                client = ObjectStoreInterface.create(src_region_tag, bucket_src)
+                src_region_tag = client.region_tag()
+                size_byte = get_usage_gbits(dst)
+            throughput_gbps = size_byte / 2**30 / request_time
+
+            # print stats
+            if not rc:
+                print_stats_completed(request_time, throughput_gbps)
+                transfer_stats = TransferStats(monitor_status="completed", total_runtime_s=request_time, throughput_gbits=throughput_gbps)
+                UsageClient.log_transfer(transfer_stats, args, src_region_tag, dst_region_tag)
             return 0
         else:
             typer.secho("Transfer not supported", fg="red")
@@ -178,7 +198,7 @@ def cp(
             num_connections=cloud_config.get_flag("num_connections"),
             max_instances=max_instances,
             solver_total_gbyte_to_transfer=sum(src_obj.size for src_obj, _ in transfer_pairs) if solve else None,
-            solver_required_throughput_gbits=solver_required_throughput_gbits,
+            solver_target_tput_per_vm_gbits=solver_target_tput_per_vm_gbits,
             solver_throughput_grid=solver_throughput_grid,
             solver_verbose=solver_verbose,
             args=args,
@@ -236,10 +256,7 @@ def cp(
                         UsageClient.log_exception("cli_verify_checksums", e, args, src_region_tag, dst_region_tag)
                         return 1
             if transfer_stats.monitor_status == "completed":
-                rprint(f"\n:white_check_mark: [bold green]Transfer completed successfully[/bold green]")
-                runtime_line = f"[white]Transfer runtime:[/white] [bright_black]{transfer_stats.total_runtime_s:.2f}s[/bright_black]"
-                throughput_line = f"[white]Throughput:[/white] [bright_black]{transfer_stats.throughput_gbits:.2f}Gbps[/bright_black]"
-                rprint(f"{runtime_line}, {throughput_line}")
+                print_stats_completed(transfer_stats.total_runtime_s, transfer_stats.throughput_gbits)
             UsageClient.log_transfer(transfer_stats, args, src_region_tag, dst_region_tag)
             return 0 if transfer_stats.monitor_status == "completed" else 1
     else:
@@ -258,7 +275,7 @@ def sync(
     multipart: bool = typer.Option(cloud_config.get_flag("multipart_enabled"), help="If true, will use multipart uploads."),
     # solver
     solve: bool = typer.Option(False, help="If true, will use solver to optimize transfer, else direct path is chosen"),
-    solver_required_throughput_gbits: float = typer.Option(4, help="Solver option: Required throughput in Gbps"),
+    solver_target_tput_per_vm_gbits: float = typer.Option(4, help="Solver option: Required throughput in Gbps per instance"),
     solver_throughput_grid: Path = typer.Option(
         skyplane_root / "profiles" / "throughput.csv", "--throughput-grid", help="Throughput grid file"
     ),
@@ -295,8 +312,8 @@ def sync(
     :type max_instances: int
     :param solve: If true, will use solver to optimize transfer, else direct path is chosen
     :type solve: bool
-    :param solver_required_throughput_gbits: The required throughput in Gbps when using the solver (default: 4)
-    :type solver_required_throughput_gbits: float
+    :param throughput_per_instance_gbits: The required throughput in Gbps per instance when using the solver (default: 4)
+    :type throughput_per_instance_gbits: float
     :param solver_throughput_grid: The throughput grid profile to use for the solver, defaults to author-provided profile
     :type solver_throughput_grid: Path
     :param solver_verbose: If true, will print out the solver's output, defaults to False
@@ -376,7 +393,7 @@ def sync(
             num_connections=cloud_config.get_flag("num_connections"),
             max_instances=max_instances,
             solver_total_gbyte_to_transfer=sum(src_obj.size for src_obj, _ in transfer_pairs) if solve else None,
-            solver_required_throughput_gbits=solver_required_throughput_gbits,
+            solver_target_tput_per_vm_gbits=solver_target_tput_per_vm_gbits,
             solver_throughput_grid=solver_throughput_grid,
             solver_verbose=solver_verbose,
             args=args,
@@ -557,7 +574,6 @@ def init(
     typer.secho(f"\nConfig file saved to {config_path}", fg="green")
 
     # Set metrics collection by default
-    print("\n")
     usage_stats_var = UsageClient.usage_stats_status()
     if usage_stats_var is UsageStatsStatus.DISABLED_EXPLICITLY:
         rprint(skyplane.cli.usage.definitions.USAGE_STATS_DISABLED_MESSAGE)
