@@ -5,6 +5,7 @@ from pathlib import Path
 
 import typer
 from rich.console import Console
+from rich import print as rprint
 
 from skyplane.compute.aws.aws_auth import AWSAuthentication
 from skyplane.compute.aws.aws_cloud_provider import AWSCloudProvider
@@ -26,7 +27,7 @@ def print_header():
  `--. \    \   \ / |  __/| |    |  _  || . ` ||  __| 
 /\__/ / |\  \  | | | |   | |____| | | || |\  || |___ 
 \____/\_| \_/  \_/ \_|   \_____/\_| |_/\_| \_/\____/"""
-    console.print(f"[blue]{header}[/blue]\n")
+    console.print(f"[bright_black]{header}[/bright_black]\n")
 
 
 def parse_path(path: str):
@@ -66,6 +67,13 @@ def parse_path(path: str):
     raise ValueError(f"Parse error {path}")
 
 
+def print_stats_completed(total_runtime_s, throughput_gbits):
+    console.print(f"\n:white_check_mark: [bold green]Transfer completed successfully[/bold green]")
+    runtime_line = f"[white]Transfer runtime:[/white] [bright_black]{total_runtime_s:.2f}s[/bright_black]"
+    throughput_line = f"[white]Throughput:[/white] [bright_black]{throughput_gbits:.2f}Gbps[/bright_black]"
+    console.print(f"{runtime_line}, {throughput_line}")
+
+
 def check_ulimit(hard_limit=1024 * 1024):
     # Get the current fs.file-max limit
     check_hard_limit = ["sysctl", "--values", "fs.file-max"]
